@@ -1,4 +1,4 @@
-// +build !go1.11
+// +build go1.11
 
 package varlink
 
@@ -8,5 +8,6 @@ import (
 )
 
 func listen(ctx context.Context, network, address string) (net.Listener, error) {
-	return net.Listen(network, address)
+	var lc net.ListenConfig
+	return lc.Listen(ctx, network, address)
 }
\ No newline at end of file
